import request from '@/utils/request'

export function GetDialysisProcessIndexChartData(params) {
  return request({
    url: '/api/dialysisprocessindex/chart',
    method: 'get',
    params:params,
  })
}

export function GetDialysisProcessIndexTableData(params) {
  return request({
    url: '/api/dialysisprocessindex/table',
    method: 'get',
    params:params,
  })
}


export function GetDialysisWatchChartData(params) {
  return request({
    url: '/api/dialysiswatch/chart',
    method: 'get',
    params:params,
  })
}


export function GetDialysisWatchTableData(params) {
  return request({
    url: '/api/dialysiswatch/table',
    method: 'get',
    params:params,
  })
}


export function GetDialysisBloodPressureChartData(params) {
  return request({
    url: '/api/dialysisbloodpressure/chart',
    method: 'get',
    params:params,
  })
}


export function GetDialysisBloodPressureTableData(params) {
  return request({
    url: '/api/dialysisbloodpressure/table',
    method: 'get',
    params:params,
  })
}




export function GetDialysisPatientBloodPressureChartData(params) {
  return request({
    url: '/api/patientdialysisbloodpressure/chart',
    method: 'get',
    params:params,
  })
}




export function GetDialysisWeightChartData(params) {
  return request({
    url: '/api/dialysisweight/chart',
    method: 'get',
    params:params,
  })
}



export function GetDialysisWeightTableData(params) {
  return request({
    url: '/api/dialysisweight/table',
    method: 'get',
    params:params,
  })
}


export function GetDialysisPatientWeightChartData(params) {
  return request({
    url: '/api/patientdialysisweight/chart',
    method: 'get',
    params:params,
  })
}



export function GetDoctorWorkloadChartData(params) {
  return request({
    url: '/api/doctorworkload/chart',
    method: 'get',
    params:params,
  })
}



export function GetDoctorWorkloadTableData(params) {
  return request({
    url: '/api/doctorworkload/table',
    method: 'get',
    params:params,
  })
}



export function GetNurseWorkloadChartData(params) {
  return request({
    url: '/api/nurseworkload/chart',
    method: 'get',
    params:params,
  })
}



export function GetNurseWorkloadTableData(params) {
  return request({
    url: '/api/nurseworkload/table',
    method: 'get',
    params:params,
  })
}



export function GetAllAdminUser() {
  return request({
    url: '/api/adminuser/all',
    method: 'get',
  })
}

export function GetDefalutPatient() {
  return request({
    url: '/api/defalutpatient/get',
    method: 'get',
  })
}





export function GetInspectionIndexInit() {
  return request({
    url: '/api/inspectionindex/init',
    method: 'get',
  })
}


export function GetRangeValue(params) {
  return request({
    url: '/api/rangevalue/get',
    method: 'get',
    params:params,

  })
}



export function GetInspectionIndexChart(params) {
  return request({
    url: '/api/inspectionindex/chart',
    method: 'get',
    params:params,

  })
}

export function GetInspectionIndexTable(params) {
  return request({
    url: '/api/inspectionindex/table',
    method: 'get',
    params:params,

  })
}

export function GetPatientInspectionIndexChart(params) {
  return request({
    url: '/api/patientinspectionindex/chart',
    method: 'get',
    params:params,

  })
}

export function GetPatientInspectionIndexBarChart(params) {
  return request({
    url: '/api/patientinspectionindex/barchart',
    method: 'get',
    params:params,

  })
}



export function GetDefaultPatient() {
  return request({
    url: '/api/defalutpatient/get',
    method: 'get',

  })
}







